# Mongita CHANGELOG

## [0.1.2] - 2021-04-23
### Added
- License added to package deployment

## [0.1.1] - 2021-04-21
### Changed
- Removed repr from result classes to be more inline with pymongo

## [0.1.0] - 2021-04-19
First release
